@@ -15,6 +15,10 @@ GVWebPage::GVWebPage(QObject *parent/* = NULL*/)
 //     webPage.settings()->setAttribute (QWebSettings::AutoLoadImages, false);
     webPage.setForwardUnsupportedContent (true);
 
+    QNetworkProxy http, https;
+    getSystemProxies (http, https);
+    QNetworkProxy::setApplicationProxy (http);
+
     garbageTimer.setSingleShot (true);
     garbageTimer.setInterval (1000 * 60 * 2);   // 2 minutes
 
@@ -1222,3 +1226,79 @@ GVWebPage::onVmailDownloaded (QNetworkReply *reply)
     completeCurrentWork (GVAW_playVmail, rv);
     reply->deleteLater ();
 }//GVWebPage::onVmailDownloaded
+
+bool
+GVWebPage::getSystemProxies (QNetworkProxy &http, QNetworkProxy &https)
+{
+    QNetworkProxyFactory::setUseSystemConfiguration (true);
+
+    do { // Begin cleanup block (not a loop)
+        QList<QNetworkProxy> netProxies =
+        QNetworkProxyFactory::systemProxyForQuery (
+        QNetworkProxyQuery(QUrl("http://www.google.com")));
+        http = netProxies[0];
+        if (QNetworkProxy::NoProxy != http.type ()) {
+            break;
+        }
+
+        // Otherwise Confirm it
+#if defined(Q_WS_X11)
+        QString strHttpProxy = getenv ("http_proxy");
+        if (strHttpProxy.isEmpty ()) {
+            break;
+        }
+
+        int colon = strHttpProxy.lastIndexOf (':');
+        if (-1 != colon) {
+            QString strHost = strHttpProxy.mid (0, colon);
+            QString strPort = strHttpProxy.mid (colon);
+
+            strHost.remove ("http://").remove ("https://");
+
+            strPort.remove (':').remove ('/');
+            int port = strPort.toInt ();
+
+            qDebug () << "Found http proxy: " << strHost << ":" << port;
+            http.setHostName (strHost);
+            http.setPort (port);
+            http.setType (QNetworkProxy::HttpProxy);
+        }
+#endif
+    } while (0); // End cleanup block (not a loop)
+
+    do { // Begin cleanup block (not a loop)
+        QList<QNetworkProxy> netProxies =
+        QNetworkProxyFactory::systemProxyForQuery (
+        QNetworkProxyQuery(QUrl("https://www.google.com")));
+        https = netProxies[0];
+        if (QNetworkProxy::NoProxy != https.type ()) {
+            break;
+        }
+
+        // Otherwise Confirm it
+#if defined(Q_WS_X11)
+        QString strHttpProxy = getenv ("https_proxy");
+        if (strHttpProxy.isEmpty ()) {
+            break;
+        }
+
+        int colon = strHttpProxy.lastIndexOf (':');
+        if (-1 != colon) {
+            QString strHost = strHttpProxy.mid (0, colon);
+            QString strPort = strHttpProxy.mid (colon);
+
+            strHost.remove ("http://").remove ("https://");
+
+            strPort.remove (':').remove ('/');
+            int port = strPort.toInt ();
+
+            qDebug () << "Found http proxy: " << strHost << ":" << port;
+            https.setHostName (strHost);
+            https.setPort (port);
+            https.setType (QNetworkProxy::HttpProxy);
+        }
+#endif
+    } while (0); // End cleanup block (not a loop)
+
+    return (true);
+}//GVWebPage::getSystemProxies
